==> bb-1.2a.tgz: bb/web/mkbb2.sh <==
#!/bin/sh

# mkbb2.sh
# SCRIPT TO MAKE THE BIG BROTHER SUMMARY WEB PAGE
# Sean MacGuire - The MacLawran Group Inc.
# Version 1.2a
# May 24th, 1999
#
# This program is Copyright (c) 1997-1999
# The MacLawran Group Inc.
# All Rights Reserved

if test ! "$BBTMP"                      # GET DEFINITIONS IF NEEDED
then
        . $BBHOME/etc/bbdef.sh          # INCLUDE STANDARD DEFINITIONS
fi

BBDATE=`${DATE}`			# SET THE DATE
BBTIME=`${DATE} "+%a %b %d @ %H:%M"`	# SET THE TIME
BKG=`${BBHOME}/web/mkbb.bkg`            # GET THE BACKGROUND COLOR

echo "
<HTML>
<HEAD>

<!--
        The Big Brother System and Network Monitor - $BBREL ($BBRELDATE)
        Copyright 1997-1999 The MacLawran Group Inc. - All Rights Reserved
        Non-commercial use only
        From: http://MacLawran.ca/bb-dnld/
        Contact: sean@MacLawran.ca
-->

<TITLE>${BKG} : Big Brother - Status @ $BBDATE</TITLE>
<META NAME=\"KEYWORDS\" CONTENT=\"big brother,MacLawran,monitoring\">
<META NAME=\"DESCRIPTION\" CONTENT=\"Big Brother System & Network Summary\">
<META HTTP-EQUIV=\"REFRESH\" CONTENT=\"30\">
<META HTTP-EQUIV=\"EXPIRES\" CONTENT=\"$BBRELDATE\">
</HEAD>

<BODY BACKGROUND="gifs/bkg-${BKG}.gif" 
        TEXT=#FFFFCC LINK="#00FFAA" VLINK="#FFFF44">
<A HREF="http://MacLawran.ca/bb-dnld/">
<IMG SRC="gifs/bb2.gif" ALT=\"BB\" WIDTH=30 HEIGHT=49 BORDER=0></A><BR>
<CENTER>
"

if test -s $BBTMP/BB
then
	echo "<TABLE BORDER=3><TR><TD COLSPAN=2 ALIGN=CENTER>
	<H3>$BBTIME</H3></TD>"

	#
	# SMM - NEW FOR 1.08
	# DISPLAY ONLY NON-GREEN COLUMNS
	#
	COLUMNS=`${BBHOME}/web/mkbb.cols 0` 	# GET OUR COLUMN HEADINGS 

	for col in $COLUMNS
	do
        	echo "<TD ALIGN=CENTER WIDTH=45><H4>
		<A HREF=\"bb-help.html#${col}\"> <I>$col</I></A></H4></TD>"
	done
	echo "</TR>"				# END THE ROW

	#
	# FOR EACH UNIQUE HOST WE CARE ABOUT
	# EXCEPT THE SUMMARY FILES...
	#
	$CAT $BBTMP/BB | $GREP -v "summary" | $SORT |
	while read line
	do
		set `basename $line | $SED "s/\./ /" `
		if test "$NAME" = $1
		then
			continue;		# ALREADY DEALT WITH THIS
		else
			NAME=$1			# IT'S A NEW ONE...
		fi
	
		if test "$FQDN" != ""
		then
			FNAME=`echo $NAME | $SED "s/\,/\./g"`
			echo "<TR><TD COLSPAN=2>"
		else
			FNAME=$NAME
			echo "<TR><TD COLSPAN=2 ALIGN=CENTER>"
		fi

		#
		# ADD HOOK FOR CUSTOM FILES HERE
		#

		if test -f "${BBNOTES}/${FNAME}.html"
        	then
                  echo "<A HREF=notes/${FNAME}.html> <B>$FNAME</B></A></TD>"
        	elif test -f "${BBNOTES}/${FNAME}.htm"
        	then
               	  echo "<A HREF=notes/${FNAME}.htm> <B>$FNAME</B></A></TD>"
		elif test -f "${BBNOTES}/${FNAME}"
		then
		  echo "<A HREF=notes/$FNAME> <B>$FNAME</B></A></TD>"
        	else
                	echo "<B>$FNAME</B></TD>"
        	fi
	
		#
		# FOR EACH OF THE THINGS WE MONITOR...
		#
		for col in $COLUMNS
		do
			if test -f ${BBLOGS}/$NAME.$col
			then
				set `${CAT} ${BBLOGS}/$NAME.$col`
				if [ -d "$BBHOME/www/html" ]
				then
					echo "<TD ALIGN=CENTER>
						<A HREF=\"html/${FNAME}.${col}.html\">
						<IMG SRC=\"gifs/$1.gif\"  ALT=\"${col}:$1\"
						HEIGHT=12 WIDTH=12 BORDER=0></A></TD>"
				else
					echo "<TD ALIGN=CENTER>
						<A HREF=\"html/$NAME.${col}\">
						<IMG SRC=\"gifs/$1.gif\"  ALT=\"${col}:$1\"
						HEIGHT=12 WIDTH=12 BORDER=0></A></TD>"
				fi
			else
				echo "<TD ALIGN=CENTER>-</TD>"
			fi
		done
		echo "</TR>"
	done
	#
	# Ruediger Schuetz (Ruediger.Schuetz@Munich.Netsurf.DE)
	# Fixed bad table ending....
	#
	echo "</TABLE>"

	#
	# NOW HANDLE SUMMARY INFO
	#
	echo "<BR><TABLE BORDER=3>"
	$CAT $BBTMP/BB | $GREP "summary" | $SORT |
	while read line
	do
		set `echo $line | $SED "s/\./ /g"`
		ROW=$2
		COL=$3
	
		#
		# HANDLE THE ROW DISPLAY 
		#
		if test "$ROW" != "$LASTROW"		# WE HAVE A NEW ROW...
		then
			if test "$LASTROW" != ""
			then
				echo "</TR>"
			fi
			echo "<TR><TD><B>$ROW</B></TD>"
			LASTROW="$ROW"
		fi
		#
		# HANDLE THE COLUMN DISPLAY
		#
		echo "<TD WIDTH=45 ALIGN=CENTER>$COL<BR>"	# COLUMN TITLE
		set `$CAT ${BBLOGS}/summary.${ROW}.${COL}`
		echo "<A HREF=$2><IMG SRC=\"gifs/$1.gif\" ALT=\"$1\""
		echo "HEIGHT=12 WIDTH=12 BORDER=0></A></TD>"
	done
		
	if test "$LASTROW" != ""
	then
		echo "</TR>"
	fi
	echo "</TABLE>"
else
	echo "<H2>$BBTIME<BR><I>All Monitored Systems OK</I></H2>"
fi

echo "<TABLE CELLPADDING=5>
	<TR><TD ALIGN=CENTER><A HREF=bb-help.html>
	<IMG SRC=gifs/buthelp.gif ALT=\"Help\" WIDTH=74 HEIGHT=29 BORDER=0 VSPACE=7></A></TD>
	<TD ALIGN=CENTER><A HREF=bb-info.html>
	<IMG SRC=gifs/butinfo.gif ALT=\"Info\" WIDTH=74 HEIGHT=29 BORDER=0 VSPACE=7></A></TD>
	<TD ALIGN=CENTER><A HREF=bb.html>
	<IMG SRC=gifs/butview.gif ALT=\"View\" WIDTH=74 HEIGHT=29 BORDER=0 VSPACE=7></A></TD>
	<TD ALIGN=CENTER><A HREF=bb-page.html>
	<IMG SRC=gifs/butpage.gif ALT=\"Page\" WIDTH=74 HEIGHT=29 BORDER=0 VSPACE=7></A></TD>
	</TR></TABLE>"


#
# SMM NEW IN 1.04 - STANDARD FOOTER
#
if test -f "${BBNOTES}/footer"
then
        echo "<P>"
	$CAT ${BBNOTES}/footer
fi
echo "</CENTER></BODY></HTML>"          # END OF HTML

==> bb-1.08a.tgz: bb/web/mkbb2.sh <==
#!/bin/sh

# mkbb2.sh
# SCRIPT TO MAKE THE BIG BROTHER SUMMARY WEB PAGE
# Sean MacGuire - The MacLawran Group Inc.
# Version 1.08a - 08 Aug 1998
#
# This program is Copyright (c) 1997, 1998
# The MacLawran Group Inc.
# All Rights Reserved

if test ! "$BBTMP"                      # GET DEFINITIONS IF NEEDED
then
        . $BBHOME/etc/bbdef.sh          # INCLUDE STANDARD DEFINITIONS
fi

BKG=`${BBHOME}/web/mkbb.bkg`            # GET THE BACKGROUND COLOR

echo "
<HTML>
<HEAD>

<!--
        The Big Brother System and Network Monitor - v.1.08a - 05 sep 1998
        Copyright 1997, 1998 The MacLawran Group Inc. - All Rights Reserved
        Non-commercial use only
        From: http://MacLawran.ca/bb-dnld/
        Contact: sean@MacLawran.ca
-->

<TITLE>Big Brother - Network status @ `$DATE`</TITLE>
<META NAME=\"KEYWORDS\" CONTENT=\"big brother,MacLawran,monitoring\">
<META NAME=\"DESCRIPTION\" CONTENT=\"Big Brother System & Network Summary\">
<META HTTP-EQUIV=\"REFRESH\" CONTENT=\"30\">
<META HTTP-EQUIV=\"EXPIRES\" CONTENT=\"`date`\">
<META HTTP-EQUIV=\"PRAGMA\" CONTENT=\"NO-CACHE\">
</HEAD>

<BODY BACKGROUND=\"gifs/bkg-${BKG}.gif\" TEXT=#FFFFFF LINK=#00FFAA 
VLINK=\"#FFFF44\" ALT=\"\">
<A HREF="http://MacLawran.ca/bb-dnld/">
<IMG SRC="gifs/bb2.gif" ALT=\"BB\" WIDTH=30 HEIGHT=49 BORDER=0></A><BR>
<CENTER>
"

if test -s $BBTMP/BB
then
	echo "<TABLE BORDER=3><TR><TD COLSPAN=2 ALIGN=CENTER>
	<H3>@ `${DATE} +%H:%M`</H3></TD>"

	#
	# SMM - NEW FOR 1.08
	# DISPLAY ONLY NON-GREEN COLUMNS
	#
	COLUMNS=`${BBHOME}/web/mkbb.cols 0` 	# GET OUR COLUMN HEADINGS 

	for col in $COLUMNS
	do
        	echo "<TD ALIGN=CENTER WIDTH=45><H4>
		<A HREF=\"bb-help.html#${col}\"> <I>$col</I></A></H4></TD>"
	done
	echo "</TR>"				# END THE ROW

	#
	# FOR EACH UNIQUE HOST WE CARE ABOUT
	# EXCEPT THE SUMMARY FILES...
	#
	$CAT $BBTMP/BB | grep -v "summary" | $SORT |
	while read line
	do
		set `basename $line | $SED "s/\./ /" `
		if test "$NAME" = $1
		then
			continue;		# ALREADY DEALT WITH THIS
		else
			NAME=$1			# IT'S A NEW ONE...
		fi
	
		if test "$FQDN" != ""
		then
			FNAME=`echo $NAME | $SED "s/\,/\./g"`
			echo "<TR><TD COLSPAN=2>"
		else
			FNAME=$NAME
			echo "<TR><TD COLSPAN=2 ALIGN=CENTER>"
		fi

		#
		# ADD HOOK FOR CUSTOM FILES HERE
		#

		if test -f "${BBNOTES}/${FNAME}.html"
        	then
                  echo "<A HREF=notes/${FNAME}.html> <B>$FNAME</B></A></TD>"
        	elif test -f "${BBNOTES}/${FNAME}.htm"
        	then
               	  echo "<A HREF=notes/${FNAME}.htm> <B>$FNAME</B></A></TD>"
		elif test -f "${BBNOTES}/${FNAME}"
		then
		  echo "<A HREF=notes/$FNAME> <B>$FNAME</B></A></TD>"
        	else
                	echo "<B>$FNAME</B></TD>"
        	fi
	
		#
		# FOR EACH OF THE THINGS WE MONITOR...
		#
		for col in $COLUMNS
		do
			if test -f ${BBLOGS}/$NAME.$col
			then
				set `${CAT} ${BBLOGS}/$NAME.$col`
				echo "<TD ALIGN=CENTER>
					<A HREF=\"logs/$NAME.$col\">
					<IMG SRC=\"gifs/$1.gif\"  ALT=\"$1\"
					HEIGHT=12 WIDTH=12 BORDER=0></A></TD>"
			else
				echo "<TD ALIGN=CENTER>-</TD>"
			fi
		done
		echo "</TR>"
	done
	#
	# Ruediger Schuetz (Ruediger.Schuetz@Munich.Netsurf.DE)
	# Fixed bad table ending....
	#
	echo "</TABLE>"

	#
	# NOW HANDLE SUMMARY INFO
	#
	echo "<BR><TABLE BORDER=3>"
	$CAT $BBTMP/BB | grep "summary" | $SORT |
	while read line
	do
		set `echo $line | $SED "s/\./ /g"`
		ROW=$2
		COL=$3
	
		#
		# HANDLE THE ROW DISPLAY 
		#
		if test "$ROW" != "$LASTROW"		# WE HAVE A NEW ROW...
		then
			if test "$LASTROW" != ""
			then
				echo "</TR>"
			fi
			echo "<TR><TD><B>$ROW</B></TD>"
			LASTROW="$ROW"
		fi
		#
		# HANDLE THE COLUMN DISPLAY
		#
		echo "<TD WIDTH=45 ALIGN=CENTER>$COL<BR>"	# COLUMN TITLE
		set `$CAT ${BBLOGS}/summary.${ROW}.${COL}`
		echo "<A HREF=$2><IMG SRC=\"gifs/$1.gif\" ALT=\"$1\""
		echo "HEIGHT=12 WIDTH=12 BORDER=0></A></TD>"
	done
		
	if test "$LASTROW" != ""
	then
		echo "</TR>"
	fi
	echo "</TABLE>"
else
	echo "<H2>At `$DATE +%H:%M`, <I>All Monitored Systems OK</I></H2>"
fi

echo "<TABLE BORDER=0 CELLPADDING=15>
	<TR><TD ALIGN=CENTER><A HREF=bb-help.html>
	<IMG SRC=gifs/buthelp.gif ALT=\"Help\" WIDTH=74 HEIGHT=29></A></TD>
	<TD ALIGN=CENTER><A HREF=bb-info.html>
	<IMG SRC=gifs/butinfo.gif ALT=\"Info\" WIDTH=74 HEIGHT=29></A></TD>
	<TD ALIGN=CENTER><A HREF=bb.html>
	<IMG SRC=gifs/butview.gif ALT=\"View\" WIDTH=74 HEIGHT=29></A></TD>
	<TD ALIGN=CENTER><A HREF=bb-page.html>
	<IMG SRC=gifs/butpage.gif ALT=\"Page\" WIDTH=74 HEIGHT=29></A></TD>
	</TR></TABLE>"


#
# SMM NEW IN 1.04 - STANDARD FOOTER
#
if test -f "${BBNOTES}/footer"
then
        echo "<P>"
	cat ${BBNOTES}/footer
fi
echo "</CENTER></BODY></HTML>"          # END OF HTML
